@@ -2,7 +2,7 @@ from schematics.models import Model
 from schematics.types import StringType, DictType, UnionType, IntType, FloatType
 
 class Preprocess(Model):
-    pipeline = StringType(required=True,choices=["FaceBlurPipeline"])
+    pipeline = StringType(required=True,choices=["FaceBlurPipeline", "OCRThinFilterPipeline"])
     config = DictType(UnionType([FloatType, IntType, StringType]))
 
     def to_dict(self):
